package Dancer::Plugin::Locale;

=head1 NAME

Dancer::Plugin::Locale - Dancer I18N plugins using Locale::TextDomain

=head1 VERSION

Version 0.0103

=cut

our $VERSION = '0.0103';

=head1 MODULES

=over

=item * L<Dancer::Plugin::Locale::Detect>

=item * L<Dancer::Plugin::Locale::TextDomain>

=back

=head1 AUTHOR

=over

=item * Nicolas Steenlant, C<< <nicolas.steenlant at ugent.be> >>

=back

=head1 LICENSE AND COPYRIGHT

Copyright 2012 Ghent University Library

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.

=cut

1;

